@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # --------------------( LICENSE                           )--------------------
-# Copyright (c) 2014-2021 Beartype authors.
+# Copyright (c) 2014-2022 Beartype authors.
 # See "LICENSE" for further details.
 
 '''
@@ -15,7 +15,7 @@ from beartype._cave._cavefast import HintGenericSubscriptedType
 from beartype._util.cache.utilcachecall import callable_cached
 from beartype._util.py.utilpyversion import IS_PYTHON_AT_LEAST_3_9
 from beartype._util.utilobject import Iota
-from beartype._util.utiltyping import TupleTypes
+from beartype._data.datatyping import TupleTypes
 from typing import Any, Set
 
 # See the "beartype.cave" submodule for further commentary.
@@ -81,7 +81,7 @@ if IS_PYTHON_AT_LEAST_3_9:
         from beartype._util.hint.pep.proposal.pep484585.utilpep484585generic import (
             get_hint_pep484585_generic_type_or_none)
 
-        # If this hint is *NOT* a class, reduce this hint to the object
+        # If this hint is *NOT* a type, reduce this hint to the object
         # originating this hint if any. See the comparable
         # is_hint_pep484_generic() tester for further details.
         hint = get_hint_pep484585_generic_type_or_none(hint)
@@ -90,13 +90,19 @@ if IS_PYTHON_AT_LEAST_3_9:
         # hint if this hint is a generic *OR* false otherwise.
         hint_bases_erased = getattr(hint, '__orig_bases__', False)
 
+        # If this hint subclasses *NO* pseudo-superclasses, this hint *CANNOT*
+        # be a generic. In this case, immediately return false.
+        if not hint_bases_erased:
+            return False
+        # Else, this hint subclasses one or more pseudo-superclasses.
+
+        # For each such pseudo-superclass...
+        #
         # Unsurprisingly, PEP 585-compliant generics have absolutely *NO*
         # commonality with PEP 484-compliant generics. While the latter are
         # trivially detectable as subclassing "typing.Generic" after type
         # erasure, the former are *NOT*. The only means of deterministically
-        # deciding whether or not any given class is a PEP 585-compliant
-        # generic is as follows:
-        #
+        # deciding whether or not a hint is a PEP 585-compliant generic is if:
         # * That class defines both the __class_getitem__() dunder method *AND*
         #   the "__orig_bases__" instance variable. Note that this condition in
         #   and of itself is insufficient to decide PEP 585-compliance as a
@@ -107,19 +113,21 @@ if IS_PYTHON_AT_LEAST_3_9:
         # * One or more objects listed in that tuple are PEP 585-compliant
         #   objects.
         #
-        # Return true only if this hint satisfies *ALL* of the above conditions.
-        # Specifically, return true only if one or more pseudo-superclasses
-        # originally subclassed by this hint are themselves PEP 585-compliant
-        # type hints.
-        #
         # Note we could technically also test that this hint defines the
         # __class_getitem__() dunder method. Since this condition suffices to
         # ensure that this hint is a PEP 585-compliant generic, however, there
         # exists little benefit to doing so.
-        return hint_bases_erased and any(
-            is_hint_pep585_builtin(hint_base_erased)
-            for hint_base_erased in hint_bases_erased
-        )
+        for hint_base_erased in hint_bases_erased:  # type: ignore[union-attr]
+            # If this pseudo-superclass is itself a PEP 585-compliant type
+            # hint, return true.
+            if is_hint_pep585_builtin(hint_base_erased):
+                return True
+            # Else, this pseudo-superclass is *NOT* PEP 585-compliant. In this
+            # case, continue to the next pseudo-superclass.
+
+        # Since *NO* such pseudo-superclasses are PEP 585-compliant, this hint
+        # is *NOT* a PEP 585-compliant generic. In this case, return false.
+        return False
 
 # Else, the active Python interpreter targets at most Python < 3.9 and thus
 # fails to support PEP 585. In this case, fallback to declaring this function
@@ -279,7 +287,7 @@ def get_hint_pep585_generic_typevars(hint: object) -> TupleTypes:
 
     Raises
     ----------
-    BeartypeDecorHintPep585Exception
+    :exc:`BeartypeDecorHintPep585Exception`
         If this hint is *not* a :pep:`585`-compliant generic.
     '''
 
