@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # --------------------( LICENSE                           )--------------------
-# Copyright (c) 2014-2021 Beartype authors.
+# Copyright (c) 2014-2022 Beartype authors.
 # See "LICENSE" for further details.
 
 '''
@@ -14,7 +14,7 @@ This private submodule is *not* intended for importation by downstream callers.
 from beartype.meta import _convert_version_str_to_tuple
 from beartype.roar._roarexc import _BeartypeUtilModuleException
 from beartype._util.py.utilpyversion import IS_PYTHON_AT_LEAST_3_8
-from beartype._util.utiltyping import TypeException
+from beartype._data.datatyping import TypeException
 
 # See the "beartype.cave" submodule for further commentary.
 __all__ = ['STAR_IMPORTS_CONSIDERED_HARMFUL']
@@ -328,62 +328,3 @@ def is_package(package_name: str) -> bool:
 
     # Be the one liner you want to see in the world.
     return is_module(f'{package_name}.__init__')
-
-# ....................{ TESTERS ~ attr : typing           }....................
-def is_module_typing_any_attr(
-    # Mandatory parameters.
-    typing_attr_basename: str,
-
-    # Optional parameters.
-    exception_cls: TypeException = _BeartypeUtilModuleException,
-) -> bool:
-    '''
-    ``True`` only if a **typing attribute** (i.e., object declared at module
-    scope by either the :mod:`typing` or :mod:`typing_extensions` modules) with
-    the passed unqualified name is importable from one or more of these
-    modules.
-
-    This function is effectively memoized for efficiency.
-
-    Parameters
-    ----------
-    typing_attr_basename : str
-        Unqualified name of the attribute to be imported from a typing module.
-
-    Returns
-    ----------
-    bool
-        ``True`` only if the :mod:`typing` or :mod:`typing_extensions` modules
-        declare an attribute with this name.
-    exception_cls : Type[Exception]
-        Type of exception to be raised by this function. Defaults to
-        :class:`BeartypeDecorHintPepException`.
-
-    Raises
-    ----------
-    :exc:`exception_cls`
-        If this name is syntactically invalid.
-
-    Warns
-    ----------
-    BeartypeModuleUnimportableWarning
-        If any of these modules raise module-scoped exceptions at importation
-        time. That said, the :mod:`typing` and :mod:`typing_extensions` modules
-        are scrupulously tested and thus unlikely to raise such exceptions.
-    '''
-
-    # Avoid circular import dependencies.
-    from beartype._util.mod.utilmodimport import (
-        import_module_typing_any_attr_or_none)
-
-    # Attribute with this name imported from either the "typing" or
-    # "typing_extensions" modules if one or more of these modules declare this
-    # attribute *OR* "None" otherwise.
-    #
-    # Note that positional rather than keyword arguments are intentionally
-    # passed to optimize memoization efficiency.
-    typing_attr = import_module_typing_any_attr_or_none(
-        typing_attr_basename, exception_cls)
-
-    # Return true only if this attribute was importable.
-    return typing_attr is not None
